summaryrefslogtreecommitdiffstats
path: root/usr.sbin
diff options
context:
space:
mode:
authorbrian <brian@FreeBSD.org>2000-03-14 01:46:09 +0000
committerbrian <brian@FreeBSD.org>2000-03-14 01:46:09 +0000
commit9c5b52bb1ff54c68085f3d991416208f25de7639 (patch)
treedbe961365e18f19df00ee52df51b62d05741ec40 /usr.sbin
parentfe41605fe0c0e256c26622b4c8e5edf23f72d7c7 (diff)
downloadFreeBSD-src-9c5b52bb1ff54c68085f3d991416208f25de7639.zip
FreeBSD-src-9c5b52bb1ff54c68085f3d991416208f25de7639.tar.gz
To avoid namespace polution in NetBSD:
``struct descriptor'' -> ``struct fdescriptor''
Diffstat (limited to 'usr.sbin')
-rw-r--r--usr.sbin/ppp/bundle.c24
-rw-r--r--usr.sbin/ppp/bundle.h8
-rw-r--r--usr.sbin/ppp/chap.c8
-rw-r--r--usr.sbin/ppp/chap.h2
-rw-r--r--usr.sbin/ppp/chat.c8
-rw-r--r--usr.sbin/ppp/chat.h2
-rw-r--r--usr.sbin/ppp/datalink.c8
-rw-r--r--usr.sbin/ppp/datalink.h2
-rw-r--r--usr.sbin/ppp/descriptor.h10
-rw-r--r--usr.sbin/ppp/ether.c6
-rw-r--r--usr.sbin/ppp/exec.c2
-rw-r--r--usr.sbin/ppp/main.c4
-rw-r--r--usr.sbin/ppp/mp.c8
-rw-r--r--usr.sbin/ppp/mp.h2
-rw-r--r--usr.sbin/ppp/physical.c12
-rw-r--r--usr.sbin/ppp/physical.h10
-rw-r--r--usr.sbin/ppp/prompt.c8
-rw-r--r--usr.sbin/ppp/prompt.h2
-rw-r--r--usr.sbin/ppp/radius.c16
-rw-r--r--usr.sbin/ppp/radius.h2
-rw-r--r--usr.sbin/ppp/server.c8
-rw-r--r--usr.sbin/ppp/server.h2
-rw-r--r--usr.sbin/ppp/tty.c2
23 files changed, 78 insertions, 78 deletions
diff --git a/usr.sbin/ppp/bundle.h b/usr.sbin/ppp/bundle.h
index 46d97c3..c6a5cb4 100644
--- a/usr.sbin/ppp/bundle.h
+++ b/usr.sbin/ppp/bundle.h
@@ -61,12 +61,12 @@ struct prompt;
struct iface;
struct bundle {
- struct descriptor desc; /* really all our datalinks */
+ struct fdescriptor desc; /* really all our datalinks */
int unit; /* The device/interface unit number */
struct {
char Name[20]; /* The /dev/XXXX name */
- int fd; /* The /dev/XXXX descriptor */
+ int fd; /* The /dev/XXXX fdescriptor */
unsigned header : 1; /* Family header sent & received ? */
} dev;
@@ -162,8 +162,8 @@ extern void bundle_StopIdleTimer(struct bundle *);
extern int bundle_IsDead(struct bundle *);
extern struct datalink *bundle2datalink(struct bundle *, const char *);
-extern void bundle_RegisterDescriptor(struct bundle *, struct descriptor *);
-extern void bundle_UnRegisterDescriptor(struct bundle *, struct descriptor *);
+extern void bundle_RegisterDescriptor(struct bundle *, struct fdescriptor *);
+extern void bundle_UnRegisterDescriptor(struct bundle *, struct fdescriptor *);
extern void bundle_SetTtyCommandMode(struct bundle *, struct datalink *);
diff --git a/usr.sbin/ppp/chap.c b/usr.sbin/ppp/chap.c
index 103a269..aee866a 100644
--- a/usr.sbin/ppp/chap.c
+++ b/usr.sbin/ppp/chap.c
@@ -331,7 +331,7 @@ chap_Respond(struct chap *chap, char *name, char *key, u_char type
}
static int
-chap_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
+chap_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
{
struct chap *chap = descriptor2chap(d);
@@ -347,7 +347,7 @@ chap_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
static int
-chap_IsSet(struct descriptor *d, const fd_set *fdset)
+chap_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct chap *chap = descriptor2chap(d);
@@ -355,7 +355,7 @@ chap_IsSet(struct descriptor *d, const fd_set *fdset)
}
static void
-chap_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+chap_Read(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
struct chap *chap = descriptor2chap(d);
int got;
@@ -411,7 +411,7 @@ chap_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
}
static int
-chap_Write(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+chap_Write(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
/* We never want to write here ! */
log_Printf(LogALERT, "chap_Write: Internal error: Bad call !\n");
diff --git a/usr.sbin/ppp/chap.h b/usr.sbin/ppp/chap.h
index 37d5c6f..7de61b4 100644
--- a/usr.sbin/ppp/chap.h
+++ b/usr.sbin/ppp/chap.h
@@ -29,7 +29,7 @@ struct physical;
#define CHAP_FAILURE 4
struct chap {
- struct descriptor desc;
+ struct fdescriptor desc;
struct {
pid_t pid;
int fd;
diff --git a/usr.sbin/ppp/chat.c b/usr.sbin/ppp/chat.c
index 984fb62..2f19db2 100644
--- a/usr.sbin/ppp/chat.c
+++ b/usr.sbin/ppp/chat.c
@@ -133,7 +133,7 @@ chat_NextChar(char *ptr, char ch)
}
static int
-chat_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
+chat_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
{
struct chat *c = descriptor2chat(d);
int special, gotabort, gottimeout, needcr;
@@ -316,7 +316,7 @@ chat_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
static int
-chat_IsSet(struct descriptor *d, const fd_set *fdset)
+chat_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct chat *c = descriptor2chat(d);
return c->argptr && physical_IsSet(&c->physical->desc, fdset);
@@ -365,7 +365,7 @@ chat_UpdateLog(struct chat *c, int in)
}
static void
-chat_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+chat_Read(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
struct chat *c = descriptor2chat(d);
@@ -479,7 +479,7 @@ chat_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
}
static int
-chat_Write(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+chat_Write(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
struct chat *c = descriptor2chat(d);
int result = 0;
diff --git a/usr.sbin/ppp/chat.h b/usr.sbin/ppp/chat.h
index 2e40bab..b8162bf 100644
--- a/usr.sbin/ppp/chat.h
+++ b/usr.sbin/ppp/chat.h
@@ -36,7 +36,7 @@
struct physical;
struct chat {
- struct descriptor desc;
+ struct fdescriptor desc;
struct physical *physical;
int state; /* Our CHAT_* status */
diff --git a/usr.sbin/ppp/datalink.c b/usr.sbin/ppp/datalink.c
index 6648cfe..988bdf4 100644
--- a/usr.sbin/ppp/datalink.c
+++ b/usr.sbin/ppp/datalink.c
@@ -241,7 +241,7 @@ datalink_LoginDone(struct datalink *dl)
}
static int
-datalink_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e,
+datalink_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e,
int *n)
{
struct datalink *dl = descriptor2datalink(d);
@@ -410,7 +410,7 @@ datalink_RemoveFromSet(struct datalink *dl, fd_set *r, fd_set *w, fd_set *e)
}
static int
-datalink_IsSet(struct descriptor *d, const fd_set *fdset)
+datalink_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct datalink *dl = descriptor2datalink(d);
@@ -437,7 +437,7 @@ datalink_IsSet(struct descriptor *d, const fd_set *fdset)
}
static void
-datalink_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+datalink_Read(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
struct datalink *dl = descriptor2datalink(d);
@@ -467,7 +467,7 @@ datalink_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
}
static int
-datalink_Write(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+datalink_Write(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
struct datalink *dl = descriptor2datalink(d);
int result = 0;
diff --git a/usr.sbin/ppp/datalink.h b/usr.sbin/ppp/datalink.h
index 721b3be..dc07651 100644
--- a/usr.sbin/ppp/datalink.h
+++ b/usr.sbin/ppp/datalink.h
@@ -52,7 +52,7 @@ struct physical;
struct bundle;
struct datalink {
- struct descriptor desc; /* We play either a physical or a chat */
+ struct fdescriptor desc; /* We play either a physical or a chat */
int state; /* Our DATALINK_* state */
struct physical *physical; /* Our link */
diff --git a/usr.sbin/ppp/descriptor.h b/usr.sbin/ppp/descriptor.h
index 77452cc..a3c1b10 100644
--- a/usr.sbin/ppp/descriptor.h
+++ b/usr.sbin/ppp/descriptor.h
@@ -38,13 +38,13 @@
struct bundle;
-struct descriptor {
+struct fdescriptor {
int type;
- int (*UpdateSet)(struct descriptor *, fd_set *, fd_set *, fd_set *, int *);
- int (*IsSet)(struct descriptor *, const fd_set *);
- void (*Read)(struct descriptor *, struct bundle *, const fd_set *);
- int (*Write)(struct descriptor *, struct bundle *, const fd_set *);
+ int (*UpdateSet)(struct fdescriptor *, fd_set *, fd_set *, fd_set *, int *);
+ int (*IsSet)(struct fdescriptor *, const fd_set *);
+ void (*Read)(struct fdescriptor *, struct bundle *, const fd_set *);
+ int (*Write)(struct fdescriptor *, struct bundle *, const fd_set *);
};
#define descriptor_UpdateSet(d, r, w, e, n) ((*(d)->UpdateSet)(d, r, w, e, n))
diff --git a/usr.sbin/ppp/ether.c b/usr.sbin/ppp/ether.c
index b06a3c2..ebcbcd3 100644
--- a/usr.sbin/ppp/ether.c
+++ b/usr.sbin/ppp/ether.c
@@ -319,7 +319,7 @@ ether_iov2device(int type, struct physical *p, struct iovec *iov, int *niov,
}
static int
-ether_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
+ether_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
{
struct physical *p = descriptor2physical(d);
struct etherdevice *dev = device2ether(p->handler);
@@ -338,7 +338,7 @@ ether_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
static int
-ether_IsSet(struct descriptor *d, const fd_set *fdset)
+ether_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct physical *p = descriptor2physical(d);
struct etherdevice *dev = device2ether(p->handler);
@@ -351,7 +351,7 @@ ether_IsSet(struct descriptor *d, const fd_set *fdset)
}
static void
-ether_DescriptorRead(struct descriptor *d, struct bundle *bundle,
+ether_DescriptorRead(struct fdescriptor *d, struct bundle *bundle,
const fd_set *fdset)
{
struct physical *p = descriptor2physical(d);
diff --git a/usr.sbin/ppp/exec.c b/usr.sbin/ppp/exec.c
index 5336dd3..c6fc5a2 100644
--- a/usr.sbin/ppp/exec.c
+++ b/usr.sbin/ppp/exec.c
@@ -166,7 +166,7 @@ exec_Create(struct physical *p)
close(fids[1]);
p->fd = fids[0];
waitpid(pid, &stat, 0);
- log_Printf(LogDEBUG, "Using descriptor %d for child\n", p->fd);
+ log_Printf(LogDEBUG, "Using fdescriptor %d for child\n", p->fd);
physical_SetupStack(p, execdevice.name, PHYSICAL_FORCE_ASYNC);
if (p->cfg.cd.necessity != CD_DEFAULT)
log_Printf(LogWARN, "Carrier settings ignored\n");
diff --git a/usr.sbin/ppp/mp.c b/usr.sbin/ppp/mp.c
index 16197b0..8f9173a 100644
--- a/usr.sbin/ppp/mp.c
+++ b/usr.sbin/ppp/mp.c
@@ -966,7 +966,7 @@ mp_SetEnddisc(struct cmdargs const *arg)
}
static int
-mpserver_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e,
+mpserver_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e,
int *n)
{
struct mpserver *s = descriptor2mpserver(d);
@@ -996,14 +996,14 @@ mpserver_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e,
}
static int
-mpserver_IsSet(struct descriptor *d, const fd_set *fdset)
+mpserver_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct mpserver *s = descriptor2mpserver(d);
return s->fd >= 0 && FD_ISSET(s->fd, fdset);
}
static void
-mpserver_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+mpserver_Read(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
struct mpserver *s = descriptor2mpserver(d);
@@ -1011,7 +1011,7 @@ mpserver_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
}
static int
-mpserver_Write(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+mpserver_Write(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
/* We never want to write here ! */
log_Printf(LogALERT, "mpserver_Write: Internal error: Bad call !\n");
diff --git a/usr.sbin/ppp/mp.h b/usr.sbin/ppp/mp.h
index e33a7ed..78587eb 100644
--- a/usr.sbin/ppp/mp.h
+++ b/usr.sbin/ppp/mp.h
@@ -60,7 +60,7 @@ struct peerid {
};
struct mpserver {
- struct descriptor desc;
+ struct fdescriptor desc;
int fd; /* listen()ing or connect()ing here */
struct sockaddr_un socket; /* On this socket */
diff --git a/usr.sbin/ppp/physical.c b/usr.sbin/ppp/physical.c
index 92d47f8..f20f2d3 100644
--- a/usr.sbin/ppp/physical.c
+++ b/usr.sbin/ppp/physical.c
@@ -97,7 +97,7 @@
#define PPPOTCPLINE "ppp"
-static int physical_DescriptorWrite(struct descriptor *, struct bundle *,
+static int physical_DescriptorWrite(struct fdescriptor *, struct bundle *,
const fd_set *);
static int
@@ -128,7 +128,7 @@ struct {
#define NDEVICES (sizeof devices / sizeof devices[0])
static int
-physical_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e,
+physical_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e,
int *n)
{
return physical_doUpdateSet(d, r, w, e, n, 0);
@@ -374,7 +374,7 @@ physical_Destroy(struct physical *p)
}
static int
-physical_DescriptorWrite(struct descriptor *d, struct bundle *bundle,
+physical_DescriptorWrite(struct fdescriptor *d, struct bundle *bundle,
const fd_set *fdset)
{
struct physical *p = descriptor2physical(d);
@@ -496,7 +496,7 @@ physical_ShowStatus(struct cmdargs const *arg)
}
void
-physical_DescriptorRead(struct descriptor *d, struct bundle *bundle,
+physical_DescriptorRead(struct fdescriptor *d, struct bundle *bundle,
const fd_set *fdset)
{
struct physical *p = descriptor2physical(d);
@@ -788,7 +788,7 @@ physical_Write(struct physical *p, const void *buf, size_t nbytes)
}
int
-physical_doUpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e,
+physical_doUpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e,
int *n, int force)
{
struct physical *p = descriptor2physical(d);
@@ -850,7 +850,7 @@ physical_RemoveFromSet(struct physical *p, fd_set *r, fd_set *w, fd_set *e)
}
int
-physical_IsSet(struct descriptor *d, const fd_set *fdset)
+physical_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct physical *p = descriptor2physical(d);
return p->fd >= 0 && FD_ISSET(p->fd, fdset);
diff --git a/usr.sbin/ppp/prompt.c b/usr.sbin/ppp/prompt.c
index 5652453..debd7ca 100644
--- a/usr.sbin/ppp/prompt.c
+++ b/usr.sbin/ppp/prompt.c
@@ -120,7 +120,7 @@ prompt_Display(struct prompt *p)
}
static int
-prompt_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
+prompt_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
{
struct prompt *p = descriptor2prompt(d);
int sets;
@@ -151,7 +151,7 @@ prompt_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
static int
-prompt_IsSet(struct descriptor *d, const fd_set *fdset)
+prompt_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct prompt *p = descriptor2prompt(d);
return p->fd_in >= 0 && FD_ISSET(p->fd_in, fdset);
@@ -170,7 +170,7 @@ prompt_ShowHelp(struct prompt *p)
}
static void
-prompt_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+prompt_Read(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
struct prompt *p = descriptor2prompt(d);
struct prompt *op;
@@ -291,7 +291,7 @@ prompt_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
}
static int
-prompt_Write(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+prompt_Write(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
/* We never want to write here ! */
log_Printf(LogALERT, "prompt_Write: Internal error: Bad call !\n");
diff --git a/usr.sbin/ppp/prompt.h b/usr.sbin/ppp/prompt.h
index cd8edc7..6e3bc32 100644
--- a/usr.sbin/ppp/prompt.h
+++ b/usr.sbin/ppp/prompt.h
@@ -38,7 +38,7 @@ struct bundle;
struct cmdargs;
struct prompt {
- struct descriptor desc;
+ struct fdescriptor desc;
int fd_in, fd_out;
struct datalink *TermMode; /* The modem we're talking directly to */
FILE *Term; /* sits on top of fd_out */
diff --git a/usr.sbin/ppp/server.c b/usr.sbin/ppp/server.c
index 0f6cb51..431599f 100644
--- a/usr.sbin/ppp/server.c
+++ b/usr.sbin/ppp/server.c
@@ -46,7 +46,7 @@
#include "prompt.h"
static int
-server_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
+server_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
{
struct server *s = descriptor2server(d);
struct prompt *p;
@@ -68,7 +68,7 @@ server_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
static int
-server_IsSet(struct descriptor *d, const fd_set *fdset)
+server_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct server *s = descriptor2server(d);
struct prompt *p;
@@ -88,7 +88,7 @@ server_IsSet(struct descriptor *d, const fd_set *fdset)
#define ADDRSZ (IN_SIZE > UN_SIZE ? IN_SIZE : UN_SIZE)
static void
-server_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+server_Read(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
struct server *s = descriptor2server(d);
char hisaddr[ADDRSZ];
@@ -162,7 +162,7 @@ server_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
}
static int
-server_Write(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+server_Write(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
/* We never want to write here ! */
log_Printf(LogALERT, "server_Write: Internal error: Bad call !\n");
diff --git a/usr.sbin/ppp/server.h b/usr.sbin/ppp/server.h
index 860f432..509099d 100644
--- a/usr.sbin/ppp/server.h
+++ b/usr.sbin/ppp/server.h
@@ -29,7 +29,7 @@
struct bundle;
struct server {
- struct descriptor desc;
+ struct fdescriptor desc;
int fd;
char passwd[50];
diff --git a/usr.sbin/ppp/tty.c b/usr.sbin/ppp/tty.c
index df6029c..dc7a1be 100644
--- a/usr.sbin/ppp/tty.c
+++ b/usr.sbin/ppp/tty.c
@@ -202,7 +202,7 @@ tty_Raw(struct physical *p)
log_Printf(LogDEBUG, "%s: Entering tty_Raw\n", p->link.name);
if (p->type != PHYS_DIRECT && p->fd >= 0 && !Online(dev))
- log_Printf(LogDEBUG, "%s: Raw: descriptor = %d, mbits = %x\n",
+ log_Printf(LogDEBUG, "%s: Raw: fdescriptor = %d, mbits = %x\n",
p->link.name, p->fd, dev->mbits);
if (!physical_IsSync(p)) {
OpenPOWER on IntegriCloud
diff --git a/usr.sbin/ppp/bundle.c b/usr.sbin/ppp/bundle.c
index 7358296..61d3fd4 100644
--- a/usr.sbin/ppp/bundle.c
+++ b/usr.sbin/ppp/bundle.c
@@ -426,7 +426,7 @@ bundle_FillQueues(struct bundle *bundle)
}
static int
-bundle_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
+bundle_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
{
struct bundle *bundle = descriptor2bundle(d);
struct datalink *dl;
@@ -475,7 +475,7 @@ bundle_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
/*
* This *MUST* be called after the datalink UpdateSet()s as it
* might be ``holding'' one of the datalinks (death-row) and
* wants to be able to de-select() it from the descriptor set.
*/
result += descriptor_UpdateSet(&bundle->ncp.mp.server.desc, r, w, e, n);
@@ -483,7 +483,7 @@ bundle_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
static int
-bundle_IsSet(struct descriptor *d, const fd_set *fdset)
+bundle_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct bundle *bundle = descriptor2bundle(d);
struct datalink *dl;
@@ -504,7 +504,7 @@ bundle_IsSet(struct descriptor *d, const fd_set *fdset)
}
static void
-bundle_DescriptorRead(struct descriptor *d, struct bundle *bundle,
+bundle_DescriptorRead(struct fdescriptor *d, struct bundle *bundle,
const fd_set *fdset)
{
struct datalink *dl;
@@ -600,7 +600,7 @@ bundle_DescriptorRead(struct descriptor *d, struct bundle *bundle,
}
static int
-bundle_DescriptorWrite(struct descriptor *d, struct bundle *bundle,
+bundle_DescriptorWrite(struct fdescriptor *d, struct bundle *bundle,
const fd_set *fdset)
{
struct datalink *dl;
@@ -872,7 +872,7 @@ bundle_Destroy(struct bundle *bundle)
/*
* Clean up the interface. We don't need to timer_Stop()s, mp_Down(),
* ipcp_CleanInterface() and bundle_DownInterface() unless we're getting
* out under exceptional conditions such as a descriptor exception.
*/
timer_Stop(&bundle->idle.timer);
timer_Stop(&bundle->choked.timer);
@@ -1463,7 +1463,7 @@ bundle_ReceiveDatalink(struct bundle *bundle, int s)
nfd = (cmsg->cmsg_len - sizeof *cmsg) / sizeof(int);
if (nfd < 2) {
- log_Printf(LogERROR, "Recvmsg: %d descriptor%s received (too few) !\n",
+ log_Printf(LogERROR, "Recvmsg: %d fdescriptor%s received (too few) !\n",
nfd, nfd == 1 ? "" : "s");
while (nfd--)
close(fd[nfd]);
@@ -1521,7 +1521,7 @@ bundle_ReceiveDatalink(struct bundle *bundle, int s)
close(fd[1]);
onfd = nfd; /* We've got this many in our array */
- nfd -= 2; /* Don't include p->fd and our reply descriptor */
+ nfd -= 2; /* Don't include p->fd and our reply fdescriptor */
niov = 1; /* Skip the version id */
dl = iov2datalink(bundle, iov, &niov, sizeof iov / sizeof *iov, fd[0],
fd + 2, &nfd);
@@ -1623,7 +1623,7 @@ bundle_SendDatalink(struct datalink *dl, int s, struct sockaddr_un *sun)
log_Printf(LogERROR, "setsockopt(SO_RCVBUF, %d): %s\n", expect,
strerror(errno));
- log_Printf(LogDEBUG, "Sending %d descriptor%s and %d bytes in scatter"
+ log_Printf(LogDEBUG, "Sending %d fdescriptor%s and %d bytes in scatter"
"/gather array\n", nfd, nfd == 1 ? "" : "s", iov[0].iov_len);
if ((got = sendmsg(s, &msg, 0)) == -1)
@@ -1633,7 +1633,7 @@ bundle_SendDatalink(struct datalink *dl, int s, struct sockaddr_un *sun)
log_Printf(LogERROR, "%s: Failed initial sendmsg: Only sent %d of %d\n",
sun->sun_path, got, iov[0].iov_len);
else {
/* We must get the ACK before closing the descriptor ! */
int res;
if ((got = read(reply[0], &newpid, sizeof newpid)) == sizeof newpid) {
@@ -1825,8 +1825,8 @@ bundle_setsid(struct bundle *bundle, int holdsession)
setuid(ID0realuid());
/*
* Hang around for a HUP. This should happen as soon as the
* ppp that we passed our ctty descriptor to closes it.
* NOTE: If this process dies, the passed descriptor becomes
* invalid and will give a select() error by setting one
* of the error fds, aborting the other ppp. We don't
* want that to happen !
@@ -475,7 +475,7 @@ bundle_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
* This *MUST* be called after the datalink UpdateSet()s as it
* might be ``holding'' one of the datalinks (death-row) and
- * wants to be able to de-select() it from the descriptor set.
+ * wants to be able to de-select() it from the fdescriptor set.
*/
result += descriptor_UpdateSet(&bundle->ncp.mp.server.desc, r, w, e, n);
@@ -872,7 +872,7 @@ bundle_Destroy(struct bundle *bundle)
* Clean up the interface. We don't need to timer_Stop()s, mp_Down(),
* ipcp_CleanInterface() and bundle_DownInterface() unless we're getting
- * out under exceptional conditions such as a descriptor exception.
+ * out under exceptional conditions such as a fdescriptor exception.
*/
timer_Stop(&bundle->idle.timer);
@@ -1633,7 +1633,7 @@ bundle_SendDatalink(struct datalink *dl, int s, struct sockaddr_un *sun)
sun->sun_path, got, iov[0].iov_len);
else {
- /* We must get the ACK before closing the descriptor ! */
+ /* We must get the ACK before closing the fdescriptor ! */
int res;
if ((got = read(reply[0], &newpid, sizeof newpid)) == sizeof newpid) {
@@ -1825,8 +1825,8 @@ bundle_setsid(struct bundle *bundle, int holdsession)
/*
* Hang around for a HUP. This should happen as soon as the
- * ppp that we passed our ctty descriptor to closes it.
- * NOTE: If this process dies, the passed descriptor becomes
+ * ppp that we passed our ctty fdescriptor to closes it.
+ * NOTE: If this process dies, the passed fdescriptor becomes
* invalid and will give a select() error by setting one
* of the error fds, aborting the other ppp. We don't
diff --git a/usr.sbin/ppp/main.c b/usr.sbin/ppp/main.c
index 10269e6..ed38119 100644
--- a/usr.sbin/ppp/main.c
+++ b/usr.sbin/ppp/main.c
@@ -580,8 +580,8 @@ DoLoop(struct bundle *bundle)
for (i = 0; i <= nfds; i++)
if (FD_ISSET(i, &efds)) {
- log_Printf(LogPHASE, "Exception detected on descriptor %d\n", i);
- /* We deal gracefully with link descriptor exceptions */
+ log_Printf(LogPHASE, "Exception detected on fdescriptor %d\n", i);
+ /* We deal gracefully with link fdescriptor exceptions */
if (!bundle_Exception(bundle, i)) {
log_Printf(LogERROR, "Exception cannot be handled !\n");
break;
diff --git a/usr.sbin/ppp/physical.h b/usr.sbin/ppp/physical.h
index c5aaea8..9946eaf 100644
--- a/usr.sbin/ppp/physical.h
+++ b/usr.sbin/ppp/physical.h
@@ -73,11 +73,11 @@ struct device {
struct physical {
struct link link;
- struct descriptor desc;
+ struct fdescriptor desc;
int type; /* What sort of PHYS_* link are we ? */
struct async async; /* Our async state */
struct hdlc hdlc; /* Our hdlc state */
- int fd; /* File descriptor for this device */
+ int fd; /* File fdescriptor for this device */
struct mbuf *out; /* mbuf that suffered a short write */
int connect_count;
struct datalink *dl; /* my owner */
@@ -148,10 +148,10 @@ extern void physical_SetDevice(struct physical *, const char *);
extern ssize_t physical_Read(struct physical *, void *, size_t);
extern ssize_t physical_Write(struct physical *, const void *, size_t);
-extern int physical_doUpdateSet(struct descriptor *, fd_set *, fd_set *,
+extern int physical_doUpdateSet(struct fdescriptor *, fd_set *, fd_set *,
fd_set *, int *, int);
-extern int physical_IsSet(struct descriptor *, const fd_set *);
-extern void physical_DescriptorRead(struct descriptor *, struct bundle *,
+extern int physical_IsSet(struct fdescriptor *, const fd_set *);
+extern void physical_DescriptorRead(struct fdescriptor *, struct bundle *,
const fd_set *);
extern void physical_Login(struct physical *, const char *);
extern int physical_RemoveFromSet(struct physical *, fd_set *, fd_set *,
diff --git a/usr.sbin/ppp/radius.c b/usr.sbin/ppp/radius.c
index e46baee..cdd30f5 100644
--- a/usr.sbin/ppp/radius.c
+++ b/usr.sbin/ppp/radius.c
@@ -225,7 +225,7 @@ radius_Process(struct radius *r, int got)
}
/*
* We've either timed out or select()ed on the read descriptor
*/
static void
radius_Continue(struct radius *r, int sel)
@@ -257,16 +257,16 @@ radius_Timeout(void *v)
* Time to call rad_continue_send_request() - something to read.
*/
static void
-radius_Read(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+radius_Read(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
radius_Continue(descriptor2radius(d), 1);
}
/*
* Behave as a struct descriptor (descriptor.h)
*/
static int
-radius_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
+radius_UpdateSet(struct fdescriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
{
struct radius *rad = descriptor2radius(d);
@@ -282,10 +282,10 @@ radius_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
/*
* Behave as a struct descriptor (descriptor.h)
*/
static int
-radius_IsSet(struct descriptor *d, const fd_set *fdset)
+radius_IsSet(struct fdescriptor *d, const fd_set *fdset)
{
struct radius *r = descriptor2radius(d);
@@ -293,10 +293,10 @@ radius_IsSet(struct descriptor *d, const fd_set *fdset)
}
/*
* Behave as a struct descriptor (descriptor.h)
*/
static int
-radius_Write(struct descriptor *d, struct bundle *bundle, const fd_set *fdset)
+radius_Write(struct fdescriptor *d, struct bundle *bundle, const fd_set *fdset)
{
/* We never want to write here ! */
log_Printf(LogALERT, "radius_Write: Internal error: Bad call !\n");
@@ -225,7 +225,7 @@ radius_Process(struct radius *r, int got)
}
/*
- * We've either timed out or select()ed on the read descriptor
+ * We've either timed out or select()ed on the read fdescriptor
*/
static void
@@ -257,16 +257,16 @@ radius_Timeout(void *v)
}
/*
- * Behave as a struct descriptor (descriptor.h)
+ * Behave as a struct fdescriptor (fdescriptor.h)
*/
static int
@@ -282,10 +282,10 @@ radius_UpdateSet(struct descriptor *d, fd_set *r, fd_set *w, fd_set *e, int *n)
}
/*
- * Behave as a struct descriptor (descriptor.h)
+ * Behave as a struct fdescriptor (fdescriptor.h)
*/
static int
@@ -293,10 +293,10 @@ radius_IsSet(struct descriptor *d, const fd_set *fdset)
}
/*
- * Behave as a struct descriptor (descriptor.h)
+ * Behave as a struct fdescriptor (fdescriptor.h)
*/
static int
diff --git a/usr.sbin/ppp/radius.h b/usr.sbin/ppp/radius.h
index ea0235f..f9fdf3b 100644
--- a/usr.sbin/ppp/radius.h
+++ b/usr.sbin/ppp/radius.h
@@ -27,7 +27,7 @@
*/
struct radius {
- struct descriptor desc; /* We're a sort of (selectable) descriptor */
+ struct fdescriptor desc; /* We're a sort of (selectable) fdescriptor */
struct {
int fd; /* We're selecting on this */
struct rad_handle *rad; /* Using this to talk to our lib */